%FunctionLowPassFilter.m
%Sean Bailey
%Biomimetics
%08/27/02

function [FilteredSignal] = FunctionLowPassFilter( Signal, CutoffFrequency, DeltaTime, FilterOrder, VerifyWithPlots )

%create lowpass filter
%type "help butterord" and "help butter" for more info
%The below specs should be strictly increasing
%LowFrequencyStop = 4;  %Hz
%LowFrequencyPass = 8;  %Hz
%HighFrequencyPass = 40;  %Hz
%HighFrequencyStop = 60;  %Hz
%set this to match sampling rate
%SamplingRate = 1/SamplingPeriod;  %Hz
%filter precision specs
%PassbandLoss = 1;  %dB
%StopbandAttenuation = 20;  %dB
%%don't need to change these
%WpVector = [LowFrequencyPass/(SamplingRate/2) HighFrequencyPass/(SamplingRate/2)];
%WsVector = [LowFrequencyStop/(SamplingRate/2) HighFrequencyStop/(SamplingRate/2)];
%[N, Wn] = buttord( WpVector, WsVector, PassbandLoss, StopbandAttenuation );
%manually select Order (N) and cutoff (Wn)
N = FilterOrder;
Wn = CutoffFrequency*DeltaTime*2;  %Cutoff/(SamplingRate/2)
[b, a] = butter( N, Wn );

%filter signal
FilteredSignal = filtfilt( b, a, Signal );

if( VerifyWithPlots )
   disp( ' ' )
	disp( 'Filter info:')
	disp( strcat( 'Order: ', num2str( N ))); 
	disp( strcat( 'Numerator: ', num2str( b ))); 
	disp( strcat( 'Denominator: ', num2str( a ))); 
	disp( ' ' )
   
   %plot stuff
	figure
	hold on
	plot( Signal, 'b' )
   plot( FilteredSignal, 'r' )
   title( 'Filtered Signal' )
   legend( 'Original', 'Filtered' )

	%prompt the user to take a look
	disp( 'Press return if it looks OK.' )
	input( '' );
	close
end

return