%Use: [filtdata,sumdata]=loaddata4(basename, nTrials, nGroups, nBrackets, frequency, cutoff, butter)
function [filtdata,sumdata]=loaddata4(basename, offset, nTrials, nGroups, nBrackets, frequency, cutoff, butter)
if (nargin<8)
    error('LOADDATA format: data=loaddata4(basename, offset, nTrials, nGroups, nPlotBrackets, frequency, cutoff, butter)');
end

%basename=input('Enter the base name for the test files [ie. ''foot'' for footA_001.dat] : ');
%nTrials=input('Enter the number of trials per setting [ie. 3] : ');
%nGroups=input('Enter the number of testing groups [ie. 4] : ');
group='ABCDEFGHIJKLMNOPQRSTUVWXYZ';

%Load all of the data into Matlab
fprintf('Loading the data...')
for i=1:nGroups
    for j=1:nTrials
        eval(['tempdata' num2str((i-1)*nTrials+j,'%03d') '=load(''' basename '_' num2str((i-1)*nTrials+j+offset-1,'%03d') '.dat'');']);
    end
end
fprintf('DONE\n')

%Get the shortest test data length
fprintf('Compiling the data...')
timelength=length(tempdata001);
n=nGroups*nTrials;
for i=1:n
    eval(['tempdata=tempdata' num2str(i,'%03d') ';']);
    n=length(tempdata);
    if n<timelength
        timelength=n;
        disp(['Truncating data to ' num2str(timelength) ' points!'])
    end
end

%Build the data array structure
n=nGroups*nTrials;
for i=1:n
    eval(['data(:,:,i)=tempdata' num2str(i,'%03d') '(1:timelength,:);']);
%    eval(['clear tempdata' num2str(i,'%03d')])
end
%clear basename group tempdata
fprintf('DONE\n')

%Process the data
fprintf('Processing the data...')
period = 1/frequency;
stoptime = period *(timelength-1);
time = 0:period:stoptime;

nvars=size(tempdata001,2);
filtdata = zeros(timelength,nvars,n);
for i=1:n
    for j = 1:6
        filtdata(:,j,i) = FunctionLowPassFilter(data(:,j,i), cutoff, period, butter, 0);
        base(i,j)=mean(filtdata(1:20,j,i));
    end
    marker = (data(:,7,i)-2.5);
    %Copy the other sensor data over
    %NOTE: May need processing at later date
    for j=7:nvars
        filtdata(:,j,i) = data(:,j,i);
        base(i,j)=mean(filtdata(1:20,j,i));
    end
    
    sumdata(1,:,i)=sum(filtdata(:,:,i))-base(i,:)*timelength;
    %Antagonistic sum
    sumdata(2,:,i)=0;
    sumdata(3,:,i)=0;
    for j=1:nvars
        for k=1:timelength
            if (filtdata(k,j,i)-base(i,j))>0
                sumdata(2,j,i)=sumdata(2,j,i)+filtdata(k,j,i)-base(i,j);
            else
                sumdata(3,j,i)=sumdata(3,j,i)+filtdata(k,j,i)-base(i,j);
            end
        end
    end
    fprintf([ num2str(i) ' '])
end
fprintf('DONE\n')

%Plot the data

%plot 3 trials worth of data (x,y,z,accel)
figure(1), hold on
for i=1:nGroups
    fprintf(['Set ' group(i) ': '])
    for j=1:nTrials
        m=(i-1)*nTrials+j;     %Test set no.
        subplot(nTrials,3,(j-1)*3+1), plot(time,filtdata(:,1,m)),xlabel('Tims [s]'),ylabel(['Trial #' num2str(j) ' - Force [N]']),title(['F_x - [' num2str(sumdata(1,1,m),'%1.1f') ':' num2str(sumdata(2,1,m),'%1.1f') ':' num2str(sumdata(3,1,m),'%1.1f') ']']);
        hold on, plot([0 stoptime],[base(m,1) base(m,1)],'k:')
        subplot(nTrials,3,(j-1)*3+2), plot(time,filtdata(:,2,m)),xlabel('Tims [s]'),ylabel('Force [N]'),title(['F_y - [' num2str(sumdata(1,2,m),'%1.1f') ':' num2str(sumdata(2,2,m),'%1.1f') ':' num2str(sumdata(3,2,m),'%1.1f') ']']);
        hold on, plot([0 stoptime],[base(m,1) base(m,2)],'k:')
        subplot(nTrials,3,(j-1)*3+3), plot(time,filtdata(:,3,m)),xlabel('Tims [s]'),ylabel('Force [N]'),title(['F_z - [' num2str(sumdata(1,3,m),'%1.1f') ':' num2str(sumdata(2,3,m),'%1.1f') ':' num2str(sumdata(3,3,m),'%1.1f') ']']);
        hold on, plot([0 stoptime],[base(m,1) base(m,3)],'k:')
%        subplot(nTrials,5,(j-1)*5+4), plot(time,filtdata(:,8,m)),xlabel('Tims [s]'),ylabel('Acc [m/s^2]'),title('a_x')
%        subplot(nTrials,5,(j-1)*5+5), plot(time,filtdata(:,9,m)),xlabel('Tims [s]'),ylabel('Acc [m/s^2]'),title('a_y')
    end
    sumdataAvg(:,:,i)=mean(sumdata(:,1:3,(i-1)*nTrials+1:i*nTrials),3);
    %select a trial set for overall comparison
    %store trial to compare
    groupSelected(i,1)=menu('Please select a trial # for group plotting','1','2','3','4','5');
    fprintf(['The selected trial : ' num2str(groupSelected(i,1)) '\n'])
    close(1);
    if groupSelected(i,1)>nTrials 
        error('Trial # does not exist!'); 
    end
    %repeat for all tests
end

%plot all groups together (w/1 set from each)
fprintf('Plotting the data...')
figure(1), hold on
figure(2), hold on
figure(3), hold on
%figure(4), hold on
%figure(5), hold on
datatitles=['F_x';'F_y';'F_z';'a_x';'a_y'];
ylabelnames=['Force [N]  ';'Force [N]  ';'Force [N]  ';'Acc [m/s^2]';'Acc [m/s^2]'];
datasets=[1;2;3;8;9];
m=nGroups/nBrackets;
plotno=1;
for i=1:nBrackets
    for j=1:m
        for k=1:3
            figure(k);
            subplot(nBrackets,m,plotno), plot(time,filtdata(:,datasets(k),(plotno-1)*nTrials+groupSelected(plotno)))
            if i==nBrackets xlabel('Time [s]'); end;
            if j==1 ylabel([ylabelnames(k,:)]); end;
            if k<4
%                title(['Set ' group(plotno) ' : Forces - [' num2str(sumdataAvg(1,k,plotno),'%1.1f') ':' num2str(sumdataAvg(2,k,plotno),'%1.1f') ':' num2str(sumdataAvg(3,k,plotno),'%1.1f') ']']);
%                title([group(plotno) ' : [' num2str(sumdataAvg(1,k,plotno),'%1.1f') ' : ' num2str(sumdataAvg(2,k,plotno),'%1.1f') ' : ' num2str(sumdataAvg(3,k,plotno),'%1.1f') ']']);
                title([group(plotno)]);
                if ((i==1)&&(j==1)) 
                    title([datatitles(k,:) ' - ' group(plotno)']);
                end
                hold on, plot([0 stoptime],[base(plotno,k) base(plotno,k)],'k:');
            else
                title(['Set ' group(plotno)])
            end
        end
        plotno=plotno+1;
    end
end
fprintf('DONE\n')


return;

%clear i j nGroups nTrials
n=1, figure(4)
while(true)
    subplot(2,1,1), plot(data(:,8,n)), subplot(2,1,2), plot(data(:,9,n))
    pause
    n=n+1
end